@@ -76,9 +76,13 @@ class MainApplication(tk.Frame):
         self.normvaluemenu = tk.StringVar()
         self.normvaluemenu.set("max")
 
+        self.errlimval = tk.StringVar()
+        self.errlimval.set("absolute")
+
         self.DoseFigureHandler = DoseFigureHandler(self)
 
         # Keybinding definitions
+        self.parent.bind("<Control-e>", lambda type: self.load_file("egs"))
         self.parent.bind("<Control-d>", lambda type: self.load_file("dp"))
         self.parent.bind("<Control-o>", lambda type: self.load_file("simulation"))
         self.parent.bind("<Control-s>", self.save_graph)
@@ -88,8 +92,18 @@ class MainApplication(tk.Frame):
         self.parent.bind("<Control-z>", self.remove_last_addition)
         self.parent.bind("<F11>", self.toggle_fullscreen)
         self.parent.bind("<MouseWheel>", self.change_x_limits)
-        self.parent.bind("<Control-plus>", lambda boolean: self.change_errlims(True))
-        self.parent.bind("<Control-minus>", lambda boolean: self.change_errlims(False))
+        self.parent.bind(
+            "<Control-Alt-Up>", lambda boolean1: self.change_errlims(True, True)
+        )
+        self.parent.bind(
+            "<Control-Alt-Down>", lambda boolean1: self.change_errlims(True, False),
+        )
+        self.parent.bind(
+            "<Control-Shift-Up>", lambda boolean1: self.change_errlims(False, True),
+        )
+        self.parent.bind(
+            "<Control-Shift-Down>", lambda boolean1: self.change_errlims(False, False),
+        )
         self.parent.bind("<Control-Up>", lambda boolean: self.change_marker_size(True))
         self.parent.bind(
             "<Control-Down>", lambda boolean: self.change_marker_size(False)
@@ -131,7 +145,7 @@ class MainApplication(tk.Frame):
             accelerator="Ctrl+O",
         )
         self.addsimmenu.add_command(
-            label="3Ddose", command=lambda: self.load_file("egs"),
+            label="3Ddose", command=lambda: self.load_file("egs"), accelerator="Ctrl+E",
         )
 
         self.filemenu.add_cascade(
@@ -336,16 +350,44 @@ class MainApplication(tk.Frame):
 
         self.errlimmenu = tk.Menu(self.menubar, tearoff=False)
         self.errlimmenu.add_command(
-            label=Text().increase[self.lang],
-            command=lambda: self.change_errlims(True),
+            label=Text().increaseupper[self.lang],
+            command=lambda: self.change_errlims(True, True),
             accelerator="Ctrl + +",
         )
 
         self.errlimmenu.add_command(
-            label=Text().decrease[self.lang],
-            command=lambda: self.change_errlims(False),
+            label=Text().decreaseupper[self.lang],
+            command=lambda: self.change_errlims(True, False),
             accelerator="Ctrl + -",
         )
+        self.errlimmenu.add_command(
+            label=Text().increselower[self.lang],
+            command=lambda: self.change_errlims(False, True),
+            accelerator="Ctrl + Alt + +",
+        )
+        self.errlimmenu.add_command(
+            label=Text().decreaselower[self.lang],
+            command=lambda: self.change_errlims(False, False),
+            accelerator="Ctrl + Alt + -",
+        )
+
+        self.errlimvalmenu = tk.Menu(self.menubar, tearoff=False)
+        self.errlimvalmenu.add_radiobutton(
+            label=self.text.percentage[self.lang],
+            variable=self.errlimval,
+            value="percentage",
+            command=self.changeerrdisplay,
+        )
+        self.errlimvalmenu.add_radiobutton(
+            label=self.text.absolute[self.lang],
+            variable=self.errlimval,
+            value="absolute",
+            command=self.changeerrdisplay,
+        )
+
+        self.errlimmenu.add_cascade(
+            label=self.text.changeerr[self.lang], menu=self.errlimvalmenu
+        )
 
         self.normmenu.add_cascade(
             label=Text().errlimmenu[self.lang], menu=self.errlimmenu
@@ -425,7 +467,8 @@ class MainApplication(tk.Frame):
         normalize = self.norm.get()
         errorbars = self.errorbars.get()
         diffplot = self.diffplot.get()
-        errlim = self.DoseFigureHandler.errlim
+        errlimmin = self.DoseFigureHandler.errlimmin
+        errlimmax = self.DoseFigureHandler.errlimmax
         self.pack_forget()
         self.parent.config(menu=None)
         self.profile.set_attribute("language", language)
@@ -441,7 +484,8 @@ class MainApplication(tk.Frame):
             self.errorbars.set(errorbars)
             self.diffplot.set(diffplot)
             self.DoseFigureHandler.diffplot = diffplot
-            self.DoseFigureHandler.errlim = errlim
+            self.DoseFigureHandler.errlimmin = errlimmin
+            self.DoseFigureHandler.errlimmax = errlimmax
             self.show_preview()
 
         return
@@ -454,7 +498,7 @@ class MainApplication(tk.Frame):
         if type == "simulation":
             filetypes = [(self.text.topas[self.lang], [".csv", ".bin"])]
         if type == "egs":
-            filetypes = [(self.text.egs[self.lang], [".csv", ".bin"])]
+            filetypes = [(self.text.egs[self.lang], [".3ddose"])]
         elif type == "pdd" or type == "dp":
             filetypes = [(self.text.measurementdata[self.lang], ["txt", ".csv"])]
         elif type == "ptw":
@@ -503,7 +547,8 @@ class MainApplication(tk.Frame):
         self.DoseFigureHandler.plots = []
         self.diffplot.set(False)
         self.DoseFigureHandler.diffplot = False
-        self.DoseFigureHandler.errlim = None
+        self.errlimmin = 1.1
+        self.errlimmax = 1.1
         self.saved = True
         self.menuflag = False
         self.DoseFigureHandler.caxcorrection = False
@@ -652,13 +697,29 @@ class MainApplication(tk.Frame):
 
         return
 
-    def change_errlims(self, boolean):
-        if boolean == True:
-            self.DoseFigureHandler.errlim[0] -= 0.02
-            self.DoseFigureHandler.errlim[1] += 0.02
+    def change_errlims(self, boolean1, boolean2):
+        if boolean1 == True:
+            if boolean2 == True:
+                self.DoseFigureHandler.errlimmax += 0.5
+            else:
+                self.DoseFigureHandler.errlimmax -= 0.5
         else:
-            self.DoseFigureHandler.errlim[0] += 0.02
-            self.DoseFigureHandler.errlim[1] -= 0.02
+            if boolean2 == True:
+                self.DoseFigureHandler.errlimmin -= 0.5
+            else:
+                self.DoseFigureHandler.errlimmin += 0.5
+
+        self.refresh()
+
+    def changeerrdisplay(self):
+
+        self.prev_difference = self.DoseFigureHandler.difference
+
+        if self.errlimval.get() == "percentage":
+            self.DoseFigureHandler.errlimval = "percentage"
+            self.DoseFigureHandler.errlimmax = 1.1
+        else:
+            self.DoseFigureHandler.errlimval = "absolute"
 
         self.refresh()
 
